==> iaxmodem_1.1.0~dfsg.orig.tar.gz: iaxmodem-1.1.0/lib/spandsp/src/v22bis_tx_fixed_rrc.h <==
#define PULSESHAPER_GAIN        0.829192f
#define PULSESHAPER_COEFF_SETS  40
static const int16_t pulseshaper[PULSESHAPER_COEFF_SETS][9] =
{
    {
            -128,     /* Filter 0 */
            -228,
            -237,
             239,
           13893,
           13893,
             239,
            -237,
            -228
    },
    {
            -121,     /* Filter 1 */
            -242,
            -302,
              63,
           15293,
           12507,
             393,
            -172,
            -210
    },
    {
            -111,     /* Filter 2 */
            -252,
            -365,
            -132,
           16699,
           11146,
             525,
            -106,
            -188
    },
    {
             -99,     /* Filter 3 */
            -258,
            -425,
            -345,
           18102,
            9816,
             634,
             -42,
            -164
    },
    {
             -84,     /* Filter 4 */
            -260,
            -480,
            -575,
           19492,
            8526,
             719,
              18,
            -138
    },
    {
             -68,     /* Filter 5 */
            -256,
            -530,
            -817,
           20859,
            7283,
             782,
              75,
            -110
    },
    {
             -49,     /* Filter 6 */
            -248,
            -573,
           -1069,
           22194,
            6093,
             821,
             128,
             -81
    },
    {
             -30,     /* Filter 7 */
            -235,
            -607,
           -1326,
           23486,
            4962,
             839,
             176,
             -51
    },
    {
              -9,     /* Filter 8 */
            -217,
            -633,
           -1586,
           24728,
            3896,
             837,
             218,
             -21
    },
    {
              12,     /* Filter 9 */
            -195,
            -650,
           -1843,
           25908,
            2898,
             815,
             254,
               8
    },
    {
              33,     /* Filter 10 */
            -169,
            -656,
           -2093,
           27019,
            1972,
             776,
             282,
              36
    },
    {
              55,     /* Filter 11 */
            -138,
            -651,
           -2331,
           28052,
            1122,
             721,
             304,
              63
    },
    {
              76,     /* Filter 12 */
            -105,
            -634,
           -2552,
           29000,
             349,
             653,
             319,
              88
    },
    {
              97,     /* Filter 13 */
             -69,
            -607,
           -2751,
           29854,
            -344,
             573,
             326,
             111
    },
    {
             116,     /* Filter 14 */
             -30,
            -568,
           -2922,
           30608,
            -960,
             483,
             326,
             131
    },
    {
             133,     /* Filter 15 */
               9,
            -517,
           -3059,
           31257,
           -1497,
             387,
             320,
             148
    },
    {
             148,     /* Filter 16 */
              49,
            -456,
           -3158,
           31794,
           -1956,
             286,
             307,
             161
    },
    {
             161,     /* Filter 17 */
              90,
            -385,
           -3212,
           32217,
           -2340,
             182,
             289,
             171
    },
    {
             171,     /* Filter 18 */
             130,
            -306,
           -3217,
           32522,
           -2649,
              78,
             265,
             178
    },
    {
             177,     /* Filter 19 */
             168,
            -218,
           -3168,
           32705,
           -2888,
             -24,
             236,
             181
    },
    {
             181,     /* Filter 20 */
             204,
            -123,
           -3060,
           32766,
           -3060,
            -123,
             204,
             181
    },
    {
             181,     /* Filter 21 */
             236,
             -24,
           -2888,
           32705,
           -3168,
            -218,
             168,
             177
    },
    {
             178,     /* Filter 22 */
             265,
              78,
           -2649,
           32522,
           -3217,
            -306,
             130,
             171
    },
    {
             171,     /* Filter 23 */
             289,
             182,
           -2340,
           32217,
           -3212,
            -385,
              90,
             161
    },
    {
             161,     /* Filter 24 */
             307,
             286,
           -1956,
           31794,
           -3158,
            -456,
              49,
             148
    },
    {
             148,     /* Filter 25 */
             320,
             387,
           -1497,
           31257,
           -3059,
            -517,
               9,
             133
    },
    {
             131,     /* Filter 26 */
             326,
             483,
            -960,
           30608,
           -2922,
            -568,
             -30,
             116
    },
    {
             111,     /* Filter 27 */
             326,
             573,
            -344,
           29854,
           -2751,
            -607,
             -69,
              97
    },
    {
              88,     /* Filter 28 */
             319,
             653,
             349,
           29000,
           -2552,
            -634,
            -105,
              76
    },
    {
              63,     /* Filter 29 */
             304,
             721,
            1122,
           28052,
           -2331,
            -651,
            -138,
              55
    },
    {
              36,     /* Filter 30 */
             282,
             776,
            1972,
           27019,
           -2093,
            -656,
            -169,
              33
    },
    {
               8,     /* Filter 31 */
             254,
             815,
            2898,
           25908,
           -1843,
            -650,
            -195,
              12
    },
    {
             -21,     /* Filter 32 */
             218,
             837,
            3896,
           24728,
           -1586,
            -633,
            -217,
              -9
    },
    {
             -51,     /* Filter 33 */
             176,
             839,
            4962,
           23486,
           -1326,
            -607,
            -235,
             -30
    },
    {
             -81,     /* Filter 34 */
             128,
             821,
            6093,
           22194,
           -1069,
            -573,
            -248,
             -49
    },
    {
            -110,     /* Filter 35 */
              75,
             782,
            7283,
           20859,
            -817,
            -530,
            -256,
             -68
    },
    {
            -138,     /* Filter 36 */
              18,
             719,
            8526,
           19492,
            -575,
            -480,
            -260,
             -84
    },
    {
            -164,     /* Filter 37 */
             -42,
             634,
            9816,
           18102,
            -345,
            -425,
            -258,
             -99
    },
    {
            -188,     /* Filter 38 */
            -106,
             525,
           11146,
           16699,
            -132,
            -365,
            -252,
            -111
    },
    {
            -210,     /* Filter 39 */
            -172,
             393,
           12507,
           15293,
              63,
            -302,
            -242,
            -121
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v22bis_tx_fixed_rrc.h <==
#define TX_PULSESHAPER_GAIN        0.829192f
#define TX_PULSESHAPER_COEFF_SETS  40
static const int16_t tx_pulseshaper[TX_PULSESHAPER_COEFF_SETS][9] =
{
    {
            -128,     /* Filter 0 */
            -228,
            -237,
             239,
           13893,
           13893,
             239,
            -237,
            -228
    },
    {
            -121,     /* Filter 1 */
            -242,
            -302,
              63,
           15293,
           12507,
             393,
            -172,
            -210
    },
    {
            -111,     /* Filter 2 */
            -252,
            -365,
            -132,
           16699,
           11146,
             525,
            -106,
            -188
    },
    {
             -99,     /* Filter 3 */
            -258,
            -425,
            -345,
           18102,
            9816,
             634,
             -42,
            -164
    },
    {
             -84,     /* Filter 4 */
            -260,
            -480,
            -575,
           19492,
            8526,
             719,
              18,
            -138
    },
    {
             -68,     /* Filter 5 */
            -256,
            -530,
            -817,
           20859,
            7283,
             782,
              75,
            -110
    },
    {
             -49,     /* Filter 6 */
            -248,
            -573,
           -1069,
           22194,
            6093,
             821,
             128,
             -81
    },
    {
             -30,     /* Filter 7 */
            -235,
            -607,
           -1326,
           23486,
            4962,
             839,
             176,
             -51
    },
    {
              -9,     /* Filter 8 */
            -217,
            -633,
           -1586,
           24728,
            3896,
             837,
             218,
             -21
    },
    {
              12,     /* Filter 9 */
            -195,
            -650,
           -1843,
           25908,
            2898,
             815,
             254,
               8
    },
    {
              33,     /* Filter 10 */
            -169,
            -656,
           -2093,
           27019,
            1972,
             776,
             282,
              36
    },
    {
              55,     /* Filter 11 */
            -138,
            -651,
           -2331,
           28052,
            1122,
             721,
             304,
              63
    },
    {
              76,     /* Filter 12 */
            -105,
            -634,
           -2552,
           29000,
             349,
             653,
             319,
              88
    },
    {
              97,     /* Filter 13 */
             -69,
            -607,
           -2751,
           29854,
            -344,
             573,
             326,
             111
    },
    {
             116,     /* Filter 14 */
             -30,
            -568,
           -2922,
           30608,
            -960,
             483,
             326,
             131
    },
    {
             133,     /* Filter 15 */
               9,
            -517,
           -3059,
           31257,
           -1497,
             387,
             320,
             148
    },
    {
             148,     /* Filter 16 */
              49,
            -456,
           -3158,
           31794,
           -1956,
             286,
             307,
             161
    },
    {
             161,     /* Filter 17 */
              90,
            -385,
           -3212,
           32217,
           -2340,
             182,
             289,
             171
    },
    {
             171,     /* Filter 18 */
             130,
            -306,
           -3217,
           32522,
           -2649,
              78,
             265,
             178
    },
    {
             177,     /* Filter 19 */
             168,
            -218,
           -3168,
           32705,
           -2888,
             -24,
             236,
             181
    },
    {
             181,     /* Filter 20 */
             204,
            -123,
           -3060,
           32767,
           -3060,
            -123,
             204,
             181
    },
    {
             181,     /* Filter 21 */
             236,
             -24,
           -2888,
           32705,
           -3168,
            -218,
             168,
             177
    },
    {
             178,     /* Filter 22 */
             265,
              78,
           -2649,
           32522,
           -3217,
            -306,
             130,
             171
    },
    {
             171,     /* Filter 23 */
             289,
             182,
           -2340,
           32217,
           -3212,
            -385,
              90,
             161
    },
    {
             161,     /* Filter 24 */
             307,
             286,
           -1956,
           31794,
           -3158,
            -456,
              49,
             148
    },
    {
             148,     /* Filter 25 */
             320,
             387,
           -1497,
           31257,
           -3059,
            -517,
               9,
             133
    },
    {
             131,     /* Filter 26 */
             326,
             483,
            -960,
           30608,
           -2922,
            -568,
             -30,
             116
    },
    {
             111,     /* Filter 27 */
             326,
             573,
            -344,
           29854,
           -2751,
            -607,
             -69,
              97
    },
    {
              88,     /* Filter 28 */
             319,
             653,
             349,
           29000,
           -2552,
            -634,
            -105,
              76
    },
    {
              63,     /* Filter 29 */
             304,
             721,
            1122,
           28052,
           -2331,
            -651,
            -138,
              55
    },
    {
              36,     /* Filter 30 */
             282,
             776,
            1972,
           27019,
           -2093,
            -656,
            -169,
              33
    },
    {
               8,     /* Filter 31 */
             254,
             815,
            2898,
           25908,
           -1843,
            -650,
            -195,
              12
    },
    {
             -21,     /* Filter 32 */
             218,
             837,
            3896,
           24728,
           -1586,
            -633,
            -217,
              -9
    },
    {
             -51,     /* Filter 33 */
             176,
             839,
            4962,
           23486,
           -1326,
            -607,
            -235,
             -30
    },
    {
             -81,     /* Filter 34 */
             128,
             821,
            6093,
           22194,
           -1069,
            -573,
            -248,
             -49
    },
    {
            -110,     /* Filter 35 */
              75,
             782,
            7283,
           20859,
            -817,
            -530,
            -256,
             -68
    },
    {
            -138,     /* Filter 36 */
              18,
             719,
            8526,
           19492,
            -575,
            -480,
            -260,
             -84
    },
    {
            -164,     /* Filter 37 */
             -42,
             634,
            9816,
           18102,
            -345,
            -425,
            -258,
             -99
    },
    {
            -188,     /* Filter 38 */
            -106,
             525,
           11146,
           16699,
            -132,
            -365,
            -252,
            -111
    },
    {
            -210,     /* Filter 39 */
            -172,
             393,
           12507,
           15293,
              63,
            -302,
            -242,
            -121
    }
};
